@@ -14,11 +14,14 @@ Takes
 
 =item value_ref
 
-A reference to the current value you're going to be massaging. C<encode> works in place, massaging whatever value_ref refers to.
+A reference to the current value you're going to be
+massaging. C<encode> works in place, massaging whatever value_ref
+refers to.
 
 =item column
 
-A L<Jifty::DBI::Column> object, whatever sort of column we're working with here.
+A L<Jifty::DBI::Column> object, whatever sort of column we're working
+with here.
 
 =back
 
@@ -61,9 +64,10 @@ sub encode {
 
 =head2 decode
 
-C<decode> takes data that the database is handing back to us and gets it into a form that's OK to hand back to the user. This could be anything
-from flattening a L<DateTime> object into an ISO date to making sure
-that data is utf8 clean.
+C<decode> takes data that the database is handing back to us and gets
+it into a form that's OK to hand back to the user. This could be
+anything from flattening a L<DateTime> object into an ISO date to
+making sure that data is utf8 clean.
 
 =cut
 
