@@ -93,24 +93,27 @@ DISTINCT result set.
 =cut
 
 sub distinct_query {
-     my $self = shift;
-     my $statementref = shift;
-    my $sb = shift;
-    my $table = $sb->table;
+    my $self         = shift;
+    my $statementref = shift;
+    my $sb           = shift;
+    my $table        = $sb->table;
+
+    if ( $sb->_order_clause =~ /(?<!main)\./ ) {
 
-    if ($sb->_order_clause =~ /(?<!main)\./) {
         # Don't know how to do ORDER BY when the DISTINCT is in a subquery
-        warn "Query will contain duplicate rows; don't how how to ORDER BY across DISTINCT";
+        warn
+            "Query will contain duplicate rows; don't how how to ORDER BY across DISTINCT";
         $$statementref = "SELECT main.* FROM $$statementref";
     } else {
-       # Wrapper select query in a subselect as Sybase doesn't allow
+
+        # Wrapper select query in a subselect as Sybase doesn't allow
         # DISTINCT against CLOB/BLOB column types.
-        $$statementref = "SELECT main.* FROM ( SELECT DISTINCT main.id FROM $$statementref ) distinctquery, $table main WHERE (main.id = distinctquery.id) ";
+        $$statementref
+            = "SELECT main.* FROM ( SELECT DISTINCT main.id FROM $$statementref ) distinctquery, $table main WHERE (main.id = distinctquery.id) ";
     }
     $$statementref .= $sb->_group_clause;
     $$statementref .= $sb->_order_clause;
 }
- 
 
 =head2 binary_safe_blobs
 
